OC.L10N.register(
    "files",
    {
    "Unknown error" : "ਅਣਜਾਣ ਗਲਤੀ",
    "Files" : "ਫਾਇਲਾਂ",
    "Rename" : "ਨਾਂ ਬਦਲੋ",
    "Delete" : "ਹਟਾਓ",
    "Download" : "ਡਾਊਨਲੋਡ",
    "Error" : "ਗਲਤੀ",
    "Settings" : "ਸੈਟਿੰਗ",
    "Upload" : "ਅੱਪਲੋਡ",
    "Cancel upload" : "ਅੱਪਲੋਡ ਰੱਦ ਕਰੋ"
},
"nplurals=2; plural=(n != 1);");
